@@ -4,6 +4,8 @@ import datetime
 import functools
 import json
 import time
+from warnings import warn
+
 import dateutil.parser
 import pytz
 import backoff as backoff_module
@@ -25,10 +27,35 @@ def strptime_with_tz(dtime):
     return d_object
 
 def strptime(dtime):
-    try:
-        return datetime.datetime.strptime(dtime, DATETIME_FMT)
-    except Exception:
-        return datetime.datetime.strptime(dtime, DATETIME_PARSE)
+    """DEPRECATED Use strptime_to_utc instead.
+
+    Parse DTIME according to DATETIME_PARSE without TZ safety.
+
+    >>> strptime("2018-01-01T00:00:00Z")
+    datetime.datetime(2018, 1, 1, 0, 0)
+
+    Requires the Z TZ signifier
+    >>> strptime("2018-01-01T00:00:00")
+    Traceback (most recent call last):
+      ...
+    ValueError: time data '2018-01-01T00:00:00' does not match format '%Y-%m-%dT%H:%M:%SZ'
+
+    Can't parse non-UTC DTs
+    >>> strptime("2018-01-01T00:00:00-04:00")
+    Traceback (most recent call last):
+      ...
+    ValueError: time data '2018-01-01T00:00:00-04:00' does not match format '%Y-%m-%dT%H:%M:%SZ'
+
+    Does not support fractional seconds
+    >>> strptime("2018-01-01T00:00:00.000000Z")
+    Traceback (most recent call last):
+      ...
+    ValueError: time data '2018-01-01T00:00:00.000000Z' does not match format '%Y-%m-%dT%H:%M:%SZ'
+    """
+
+    warn("Use strptime_to_utc instead", DeprecationWarning, stacklevel=2)
+
+    return datetime.datetime.strptime(dtime, DATETIME_PARSE)
 
 def strptime_to_utc(dtimestr):
     d_object = dateutil.parser.parse(dtimestr)
@@ -195,3 +222,73 @@ def handle_top_exception(logger):
                 raise
         return wrapped
     return decorator
+
+
+def should_sync_field(inclusion, selected, default=False):
+    """
+    Returns True if a field should be synced.
+
+    inclusion: automatic|available|unsupported
+    selected: True|False|None
+    default: (default: False) True|False
+
+    "automatic" inclusion always returns True:
+    >>> should_sync_field("automatic", None, False)
+    True
+    >>> should_sync_field("automatic", True, False)
+    True
+    >>> should_sync_field("automatic", False, False)
+    True
+    >>> should_sync_field("automatic", None, True)
+    True
+    >>> should_sync_field("automatic", True, True)
+    True
+    >>> should_sync_field("automatic", False, True)
+    True
+
+
+    "unsupported" inclusion always returns False
+    >>> should_sync_field("unsupported", None, False)
+    False
+    >>> should_sync_field("unsupported", True, False)
+    False
+    >>> should_sync_field("unsupported", False, False)
+    False
+    >>> should_sync_field("unsupported", None, True)
+    False
+    >>> should_sync_field("unsupported", True, True)
+    False
+    >>> should_sync_field("unsupported", False, True)
+    False
+
+    "available" inclusion uses the selected value when set
+    >>> should_sync_field("available", True, False)
+    True
+    >>> should_sync_field("available", False, False)
+    False
+    >>> should_sync_field("available", True, True)
+    True
+    >>> should_sync_field("available", False, True)
+    False
+
+    "available" inclusion uses the default value when selected is None
+    >>> should_sync_field("available", None, False)
+    False
+    >>> should_sync_field("available", None, True)
+    True
+    """
+    # always select automatic fields
+    if inclusion == "automatic":
+        return True
+
+    # never select unsupported fields
+    if inclusion == "unsupported":
+        return False
+
+    # at this point inclusion == "available"
+    # selected could be None, otherwise use the value of selected
+    if selected is not None:
+        return selected
+
+    # if there was no selected value, use the default
+    return default
